==> haskell-numbers-3000.2.0.2-145.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-I6DBfS1WX2DI2Gb7ccc7ve
key:                  numbers-3000.2.0.2-I6DBfS1WX2DI2Gb7ccc7ve
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  60312542d28b70d5dac25d6449de5efa
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/numbers-3000.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-I6DBfS1WX2DI2Gb7ccc7ve
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-numbers-3000.2.0.2-146-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-LXB5BH3qRUK8NJsR735F7p
key:                  numbers-3000.2.0.2-LXB5BH3qRUK8NJsR735F7p
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  3bbff63c8d6de26a0ee8f7aafd5e287a
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/numbers-3000.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-LXB5BH3qRUK8NJsR735F7p
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
